## autocluster

``autocluster`` is an automated machine learning toolkit for performing clustering tasks.

## How to get started?
- First, install [SMAC](https://automl.github.io/SMAC3/stable/installation.html).
- ``pip install autocluster``

## Examples
Examples are available in these [notebooks](/autocluster/examples/).

## Disclaimer
The project is experimental and still under development.
